# Memory & Device Utilities

Functions for managing device placement, memory-aware transfers, and memory reporting.

::: torchlinops.utils.get_device

::: torchlinops.utils.device_ordinal

::: torchlinops.utils.memory_aware_to

::: torchlinops.utils.memory_aware_deepcopy

::: torchlinops.utils.ModuleMemoryMap
    options:
        inherited_members: false
        members:
            - register_module
            - memory_aware_to
            - memory_aware_deepcopy

::: torchlinops.utils.MemReporter
    options:
        inherited_members: false
        members:
            - __init__
            - report

::: torchlinops.utils.cdata

::: torchlinops.utils.tensor_memory_span

::: torchlinops.utils.same_storage
